# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AdGroupAdServiceResponsiveVideoAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'button_text': 'AdGroupAdServiceButtonText',
        'description': 'str',
        'display_url': 'str',
        'headline': 'str',
        'is_remove_video10_sec_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_video25_percent_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_video3_sec_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_video50_percent_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_video75_percent_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_video_complete_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'is_remove_video_start_beacon_urls': 'AdGroupAdServiceIsRemoveFlg',
        'logo_media_id': 'int',
        'principal': 'str',
        'thumbnail_media_id': 'int',
        'url': 'str',
        'video10_sec_beacon_urls': 'list[str]',
        'video25_percent_beacon_urls': 'list[str]',
        'video3_sec_beacon_urls': 'list[str]',
        'video50_percent_beacon_urls': 'list[str]',
        'video75_percent_beacon_urls': 'list[str]',
        'video_complete_beacon_urls': 'list[str]',
        'video_start_beacon_urls': 'list[str]'
    }

    attribute_map = {
        'button_text': 'buttonText',
        'description': 'description',
        'display_url': 'displayUrl',
        'headline': 'headline',
        'is_remove_video10_sec_beacon_urls': 'isRemoveVideo10SecBeaconUrls',
        'is_remove_video25_percent_beacon_urls': 'isRemoveVideo25PercentBeaconUrls',
        'is_remove_video3_sec_beacon_urls': 'isRemoveVideo3SecBeaconUrls',
        'is_remove_video50_percent_beacon_urls': 'isRemoveVideo50PercentBeaconUrls',
        'is_remove_video75_percent_beacon_urls': 'isRemoveVideo75PercentBeaconUrls',
        'is_remove_video_complete_beacon_urls': 'isRemoveVideoCompleteBeaconUrls',
        'is_remove_video_start_beacon_urls': 'isRemoveVideoStartBeaconUrls',
        'logo_media_id': 'logoMediaId',
        'principal': 'principal',
        'thumbnail_media_id': 'thumbnailMediaId',
        'url': 'url',
        'video10_sec_beacon_urls': 'video10SecBeaconUrls',
        'video25_percent_beacon_urls': 'video25PercentBeaconUrls',
        'video3_sec_beacon_urls': 'video3SecBeaconUrls',
        'video50_percent_beacon_urls': 'video50PercentBeaconUrls',
        'video75_percent_beacon_urls': 'video75PercentBeaconUrls',
        'video_complete_beacon_urls': 'videoCompleteBeaconUrls',
        'video_start_beacon_urls': 'videoStartBeaconUrls'
    }

    def __init__(self, button_text=None, description=None, display_url=None, headline=None, is_remove_video10_sec_beacon_urls=None, is_remove_video25_percent_beacon_urls=None, is_remove_video3_sec_beacon_urls=None, is_remove_video50_percent_beacon_urls=None, is_remove_video75_percent_beacon_urls=None, is_remove_video_complete_beacon_urls=None, is_remove_video_start_beacon_urls=None, logo_media_id=None, principal=None, thumbnail_media_id=None, url=None, video10_sec_beacon_urls=None, video25_percent_beacon_urls=None, video3_sec_beacon_urls=None, video50_percent_beacon_urls=None, video75_percent_beacon_urls=None, video_complete_beacon_urls=None, video_start_beacon_urls=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceResponsiveVideoAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._button_text = None
        self._description = None
        self._display_url = None
        self._headline = None
        self._is_remove_video10_sec_beacon_urls = None
        self._is_remove_video25_percent_beacon_urls = None
        self._is_remove_video3_sec_beacon_urls = None
        self._is_remove_video50_percent_beacon_urls = None
        self._is_remove_video75_percent_beacon_urls = None
        self._is_remove_video_complete_beacon_urls = None
        self._is_remove_video_start_beacon_urls = None
        self._logo_media_id = None
        self._principal = None
        self._thumbnail_media_id = None
        self._url = None
        self._video10_sec_beacon_urls = None
        self._video25_percent_beacon_urls = None
        self._video3_sec_beacon_urls = None
        self._video50_percent_beacon_urls = None
        self._video75_percent_beacon_urls = None
        self._video_complete_beacon_urls = None
        self._video_start_beacon_urls = None
        self.discriminator = None

        self.button_text = button_text
        self.description = description
        self.display_url = display_url
        self.headline = headline
        self.is_remove_video10_sec_beacon_urls = is_remove_video10_sec_beacon_urls
        self.is_remove_video25_percent_beacon_urls = is_remove_video25_percent_beacon_urls
        self.is_remove_video3_sec_beacon_urls = is_remove_video3_sec_beacon_urls
        self.is_remove_video50_percent_beacon_urls = is_remove_video50_percent_beacon_urls
        self.is_remove_video75_percent_beacon_urls = is_remove_video75_percent_beacon_urls
        self.is_remove_video_complete_beacon_urls = is_remove_video_complete_beacon_urls
        self.is_remove_video_start_beacon_urls = is_remove_video_start_beacon_urls
        self.logo_media_id = logo_media_id
        self.principal = principal
        self.thumbnail_media_id = thumbnail_media_id
        self.url = url
        self.video10_sec_beacon_urls = video10_sec_beacon_urls
        self.video25_percent_beacon_urls = video25_percent_beacon_urls
        self.video3_sec_beacon_urls = video3_sec_beacon_urls
        self.video50_percent_beacon_urls = video50_percent_beacon_urls
        self.video75_percent_beacon_urls = video75_percent_beacon_urls
        self.video_complete_beacon_urls = video_complete_beacon_urls
        self.video_start_beacon_urls = video_start_beacon_urls

    @property
    def button_text(self):
        """Gets the button_text of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The button_text of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceButtonText
        """
        return self._button_text

    @button_text.setter
    def button_text(self, button_text):
        """Sets the button_text of this AdGroupAdServiceResponsiveVideoAd.


        :param button_text: The button_text of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceButtonText
        """

        self._button_text = button_text

    @property
    def description(self):
        """Gets the description of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 広告の説明文です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad description.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The description of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 広告の説明文です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad description.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param description: The description of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_url(self):
        """Gets the display_url of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 表示URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ・標準キャンペーンの場合<br> &nbsp;&nbsp;ADDでは入力必須です。SETでの入力は任意です。<br> ・アプリキャンペーンの場合<br> &nbsp;&nbsp;ADD、SETのどちらも指定できません。<br> &nbsp;&nbsp;※アプリキャンペーンで指定したDeviceOsTypeに基づき、以下のいずれかのURLが自動で設定されます。<br> &nbsp;&nbsp;&nbsp;&nbsp;- iOSの場合：itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- Androidの場合：play.google.com<br> </div> <div lang=\"en\"> Display URL.<br> This field is optional in ADD and SET operation.<br> - Standard campaign:<br> &nbsp;&nbsp;Required for ADD, optional for SET.<br> - Mobile app campaign:<br> &nbsp;&nbsp;Not allowed for ADD and SET.<br> &nbsp;&nbsp;*Based on DeviceOsType specified on Mobile app campaign, any of the following URLs will be automatically set.<br> &nbsp;&nbsp;&nbsp;&nbsp;- For iOS : itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- For Android : play.google.com<br> </div>   # noqa: E501

        :return: The display_url of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: str
        """
        return self._display_url

    @display_url.setter
    def display_url(self, display_url):
        """Sets the display_url of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 表示URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ・標準キャンペーンの場合<br> &nbsp;&nbsp;ADDでは入力必須です。SETでの入力は任意です。<br> ・アプリキャンペーンの場合<br> &nbsp;&nbsp;ADD、SETのどちらも指定できません。<br> &nbsp;&nbsp;※アプリキャンペーンで指定したDeviceOsTypeに基づき、以下のいずれかのURLが自動で設定されます。<br> &nbsp;&nbsp;&nbsp;&nbsp;- iOSの場合：itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- Androidの場合：play.google.com<br> </div> <div lang=\"en\"> Display URL.<br> This field is optional in ADD and SET operation.<br> - Standard campaign:<br> &nbsp;&nbsp;Required for ADD, optional for SET.<br> - Mobile app campaign:<br> &nbsp;&nbsp;Not allowed for ADD and SET.<br> &nbsp;&nbsp;*Based on DeviceOsType specified on Mobile app campaign, any of the following URLs will be automatically set.<br> &nbsp;&nbsp;&nbsp;&nbsp;- For iOS : itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- For Android : play.google.com<br> </div>   # noqa: E501

        :param display_url: The display_url of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: str
        """

        self._display_url = display_url

    @property
    def headline(self):
        """Gets the headline of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 広告のタイトルです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad title.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The headline of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: str
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """Sets the headline of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 広告のタイトルです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Ad title.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param headline: The headline of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: str
        """

        self._headline = headline

    @property
    def is_remove_video10_sec_beacon_urls(self):
        """Gets the is_remove_video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video10_sec_beacon_urls

    @is_remove_video10_sec_beacon_urls.setter
    def is_remove_video10_sec_beacon_urls(self, is_remove_video10_sec_beacon_urls):
        """Sets the is_remove_video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video10_sec_beacon_urls: The is_remove_video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video10_sec_beacon_urls = is_remove_video10_sec_beacon_urls

    @property
    def is_remove_video25_percent_beacon_urls(self):
        """Gets the is_remove_video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video25_percent_beacon_urls

    @is_remove_video25_percent_beacon_urls.setter
    def is_remove_video25_percent_beacon_urls(self, is_remove_video25_percent_beacon_urls):
        """Sets the is_remove_video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video25_percent_beacon_urls: The is_remove_video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video25_percent_beacon_urls = is_remove_video25_percent_beacon_urls

    @property
    def is_remove_video3_sec_beacon_urls(self):
        """Gets the is_remove_video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video3_sec_beacon_urls

    @is_remove_video3_sec_beacon_urls.setter
    def is_remove_video3_sec_beacon_urls(self, is_remove_video3_sec_beacon_urls):
        """Sets the is_remove_video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video3_sec_beacon_urls: The is_remove_video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video3_sec_beacon_urls = is_remove_video3_sec_beacon_urls

    @property
    def is_remove_video50_percent_beacon_urls(self):
        """Gets the is_remove_video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video50_percent_beacon_urls

    @is_remove_video50_percent_beacon_urls.setter
    def is_remove_video50_percent_beacon_urls(self, is_remove_video50_percent_beacon_urls):
        """Sets the is_remove_video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video50_percent_beacon_urls: The is_remove_video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video50_percent_beacon_urls = is_remove_video50_percent_beacon_urls

    @property
    def is_remove_video75_percent_beacon_urls(self):
        """Gets the is_remove_video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video75_percent_beacon_urls

    @is_remove_video75_percent_beacon_urls.setter
    def is_remove_video75_percent_beacon_urls(self, is_remove_video75_percent_beacon_urls):
        """Sets the is_remove_video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video75_percent_beacon_urls: The is_remove_video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video75_percent_beacon_urls = is_remove_video75_percent_beacon_urls

    @property
    def is_remove_video_complete_beacon_urls(self):
        """Gets the is_remove_video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video_complete_beacon_urls

    @is_remove_video_complete_beacon_urls.setter
    def is_remove_video_complete_beacon_urls(self, is_remove_video_complete_beacon_urls):
        """Sets the is_remove_video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video_complete_beacon_urls: The is_remove_video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video_complete_beacon_urls = is_remove_video_complete_beacon_urls

    @property
    def is_remove_video_start_beacon_urls(self):
        """Gets the is_remove_video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501


        :return: The is_remove_video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemoveFlg
        """
        return self._is_remove_video_start_beacon_urls

    @is_remove_video_start_beacon_urls.setter
    def is_remove_video_start_beacon_urls(self, is_remove_video_start_beacon_urls):
        """Sets the is_remove_video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.


        :param is_remove_video_start_beacon_urls: The is_remove_video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemoveFlg
        """

        self._is_remove_video_start_beacon_urls = is_remove_video_start_beacon_urls

    @property
    def logo_media_id(self):
        """Gets the logo_media_id of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> ロゴの画像IDです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Logo image ID.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :return: The logo_media_id of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: int
        """
        return self._logo_media_id

    @logo_media_id.setter
    def logo_media_id(self, logo_media_id):
        """Sets the logo_media_id of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> ロゴの画像IDです。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Logo image ID.<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :param logo_media_id: The logo_media_id of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: int
        """

        self._logo_media_id = logo_media_id

    @property
    def principal(self):
        """Gets the principal of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 広告の主体者表記です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Advertiser Indication of the ad.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The principal of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: str
        """
        return self._principal

    @principal.setter
    def principal(self, principal):
        """Sets the principal of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 広告の主体者表記です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Advertiser Indication of the ad.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param principal: The principal of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: str
        """

        self._principal = principal

    @property
    def thumbnail_media_id(self):
        """Gets the thumbnail_media_id of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> サムネイルIDです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Thumbnail ID.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The thumbnail_media_id of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: int
        """
        return self._thumbnail_media_id

    @thumbnail_media_id.setter
    def thumbnail_media_id(self, thumbnail_media_id):
        """Sets the thumbnail_media_id of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> サムネイルIDです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Thumbnail ID.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param thumbnail_media_id: The thumbnail_media_id of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: int
        """

        self._thumbnail_media_id = thumbnail_media_id

    @property
    def url(self):
        """Gets the url of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> リンク先URLです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Destination URL.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The url of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> リンク先URLです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Destination URL.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param url: The url of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def video10_sec_beacon_urls(self):
        """Gets the video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 10秒視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (10 seconds).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video10_sec_beacon_urls

    @video10_sec_beacon_urls.setter
    def video10_sec_beacon_urls(self, video10_sec_beacon_urls):
        """Sets the video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 10秒視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (10 seconds).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video10_sec_beacon_urls: The video10_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video10_sec_beacon_urls = video10_sec_beacon_urls

    @property
    def video25_percent_beacon_urls(self):
        """Gets the video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 25％再生視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Playback viewing beacon URL (25%).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video25_percent_beacon_urls

    @video25_percent_beacon_urls.setter
    def video25_percent_beacon_urls(self, video25_percent_beacon_urls):
        """Sets the video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 25％再生視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Playback viewing beacon URL (25%).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video25_percent_beacon_urls: The video25_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video25_percent_beacon_urls = video25_percent_beacon_urls

    @property
    def video3_sec_beacon_urls(self):
        """Gets the video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 3秒視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (3 seconds).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video3_sec_beacon_urls

    @video3_sec_beacon_urls.setter
    def video3_sec_beacon_urls(self, video3_sec_beacon_urls):
        """Sets the video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 3秒視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (3 seconds).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video3_sec_beacon_urls: The video3_sec_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video3_sec_beacon_urls = video3_sec_beacon_urls

    @property
    def video50_percent_beacon_urls(self):
        """Gets the video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 50％再生視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Playback viewing beacon URL (50%).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video50_percent_beacon_urls

    @video50_percent_beacon_urls.setter
    def video50_percent_beacon_urls(self, video50_percent_beacon_urls):
        """Sets the video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 50％再生視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Playback viewing beacon URL (50%).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video50_percent_beacon_urls: The video50_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video50_percent_beacon_urls = video50_percent_beacon_urls

    @property
    def video75_percent_beacon_urls(self):
        """Gets the video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 75％再生視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Playback viewing beacon URL (75%).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video75_percent_beacon_urls

    @video75_percent_beacon_urls.setter
    def video75_percent_beacon_urls(self, video75_percent_beacon_urls):
        """Sets the video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 75％再生視聴ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Playback viewing beacon URL (75%).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video75_percent_beacon_urls: The video75_percent_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video75_percent_beacon_urls = video75_percent_beacon_urls

    @property
    def video_complete_beacon_urls(self):
        """Gets the video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 再生完了ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (complete).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video_complete_beacon_urls

    @video_complete_beacon_urls.setter
    def video_complete_beacon_urls(self, video_complete_beacon_urls):
        """Sets the video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 再生完了ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (complete).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video_complete_beacon_urls: The video_complete_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video_complete_beacon_urls = video_complete_beacon_urls

    @property
    def video_start_beacon_urls(self):
        """Gets the video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501

        <div lang=\"ja\"> 再生開始ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (start).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :return: The video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :rtype: list[str]
        """
        return self._video_start_beacon_urls

    @video_start_beacon_urls.setter
    def video_start_beacon_urls(self, video_start_beacon_urls):
        """Sets the video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.

        <div lang=\"ja\"> 再生開始ビーコンURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※SET時はすべて上書きされます。<br> ※httpsのURLのみ設定可能です。 </div> <div lang=\"en\"> Viewing beacon URL (start).<br> This field is optional in ADD and SET operation.<br> ∗Replace all URLs in SET operation.<br> ∗Available URL is only &#34;https&#34;. </div>   # noqa: E501

        :param video_start_beacon_urls: The video_start_beacon_urls of this AdGroupAdServiceResponsiveVideoAd.  # noqa: E501
        :type: list[str]
        """

        self._video_start_beacon_urls = video_start_beacon_urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceResponsiveVideoAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceResponsiveVideoAd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.stats_service_ad_stats_value import StatsServiceAdStatsValue  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestStatsServiceAdStatsValue(unittest.TestCase):
    """StatsServiceAdStatsValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatsServiceAdStatsValue
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.stats_service_ad_stats_value.StatsServiceAdStatsValue()  # noqa: E501
        if include_optional :
            return StatsServiceAdStatsValue(
                campaign_id = 56,
                campaign_name = '0',
                ad_group_id = 56,
                ad_group_name = '0',
                ad_id = 56,
                ad_name = '0',
                stats = yahoo_ads_display.models.stats.Stats(
                    imps = 56,
                    imps_prev = 1.337,
                    click_cnt = 56,
                    click_rate = 1.337,
                    click_rate_prev = 1.337,
                    cost = 1.337,
                    avg_cpc = 1.337,
                    conversions = 56,
                    conversion_rate = 1.337,
                    conversions_via_ad_click = 56,
                    conversion_rate_via_ad_click = 1.337,
                    all_conversions = 56,
                    all_conversion_rate = 1.337,
                    cpa = '0',
                    conversion_value = '0',
                    value_per_conversions = '0',
                    conv_value_per_cost = 1.337,
                    all_conv_value_per_cost = 1.337,
                    conv_value_via_ad_click_per_cost = 1.337,
                    all_conversion_value = '0',
                    value_per_all_conversions = '0',
                    conversion_value_via_ad_click = '0',
                    value_per_conversions_via_ad_click = '0',
                    cpa_via_ad_click = '0',
                    all_cpa = '0',
                    cross_device_conversions = 56,
                    avg_deliver_rank = 1.337,
                    measured_imps = 1.337,
                    total_vimps = 56,
                    measured_imps_rate = 1.337,
                    vimps = 56,
                    viewable_imps_rate = 1.337,
                    in_view_rate = 1.337,
                    viewable_clicks = 1.337,
                    in_view_click_cnt = 56,
                    viewable_click_rate = 1.337,
                    in_view_click_rate = 1.337,
                    paid_video_views = 56,
                    paid_video_view_rate = 1.337,
                    average_cpv = 1.337,
                    video_views = 56,
                    video_views_to25 = 56,
                    video_views_to50 = 56,
                    video_views_to75 = 56,
                    video_views_to95 = 56,
                    video_views_to100 = 56,
                    video_views_to3_sec = 56,
                    video_views_to10_sec = 56,
                    average_rate_video_viewed = 1.337,
                    average_duration_video_viewed = 1.337,
                    impression_share = 1.337,
                    budget_impression_share_lost_rate = 1.337,
                    rank_impression_share_lost_rate = 1.337, )
            )
        else :
            return StatsServiceAdStatsValue(
        )

    def testStatsServiceAdStatsValue(self):
        """Test StatsServiceAdStatsValue"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class Account(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_authorities': 'list[str]',
        'account_id': 'int',
        'account_name': 'str',
        'account_status': 'AccountServiceStatus',
        'account_type': 'AccountServiceType',
        'auth_type': 'AccountServiceAuthType',
        'auto_tagging_enabled': 'AccountServiceAutoTaggingEnabled',
        'budget': 'AccountServiceBudget',
        'delivery_status': 'AccountServiceDeliveryStatus',
        'is_test_account': 'AccountServiceIsTestAccount'
    }

    attribute_map = {
        'account_authorities': 'accountAuthorities',
        'account_id': 'accountId',
        'account_name': 'accountName',
        'account_status': 'accountStatus',
        'account_type': 'accountType',
        'auth_type': 'authType',
        'auto_tagging_enabled': 'autoTaggingEnabled',
        'budget': 'budget',
        'delivery_status': 'deliveryStatus',
        'is_test_account': 'isTestAccount'
    }

    def __init__(self, account_authorities=None, account_id=None, account_name=None, account_status=None, account_type=None, auth_type=None, auto_tagging_enabled=None, budget=None, delivery_status=None, is_test_account=None, local_vars_configuration=None):  # noqa: E501
        """Account - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_authorities = None
        self._account_id = None
        self._account_name = None
        self._account_status = None
        self._account_type = None
        self._auth_type = None
        self._auto_tagging_enabled = None
        self._budget = None
        self._delivery_status = None
        self._is_test_account = None
        self.discriminator = None

        self.account_authorities = account_authorities
        self.account_id = account_id
        self.account_name = account_name
        self.account_status = account_status
        self.account_type = account_type
        self.auth_type = auth_type
        self.auto_tagging_enabled = auto_tagging_enabled
        self.budget = budget
        self.delivery_status = delivery_status
        self.is_test_account = is_test_account

    @property
    def account_authorities(self):
        """Gets the account_authorities of this Account.  # noqa: E501

        <div lang=\"ja\">アカウント権限です。</div> <div lang=\"en\">Account authority.</div>   # noqa: E501

        :return: The account_authorities of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_authorities

    @account_authorities.setter
    def account_authorities(self, account_authorities):
        """Sets the account_authorities of this Account.

        <div lang=\"ja\">アカウント権限です。</div> <div lang=\"en\">Account authority.</div>   # noqa: E501

        :param account_authorities: The account_authorities of this Account.  # noqa: E501
        :type: list[str]
        """

        self._account_authorities = account_authorities

    @property
    def account_id(self):
        """Gets the account_id of this Account.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> SET時、このフィールドは必須となります。 </div> <div lang=\"en\"> Account ID.<br> This field is required in SET operation. </div>   # noqa: E501

        :return: The account_id of this Account.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Account.

        <div lang=\"ja\"> アカウントIDです。<br> SET時、このフィールドは必須となります。 </div> <div lang=\"en\"> Account ID.<br> This field is required in SET operation. </div>   # noqa: E501

        :param account_id: The account_id of this Account.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def account_name(self):
        """Gets the account_name of this Account.  # noqa: E501

        <div lang=\"ja\"> アカウント名です。<br> SET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Account name.<br> This field is optional in SET operation. </div>   # noqa: E501

        :return: The account_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this Account.

        <div lang=\"ja\"> アカウント名です。<br> SET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Account name.<br> This field is optional in SET operation. </div>   # noqa: E501

        :param account_name: The account_name of this Account.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def account_status(self):
        """Gets the account_status of this Account.  # noqa: E501


        :return: The account_status of this Account.  # noqa: E501
        :rtype: AccountServiceStatus
        """
        return self._account_status

    @account_status.setter
    def account_status(self, account_status):
        """Sets the account_status of this Account.


        :param account_status: The account_status of this Account.  # noqa: E501
        :type: AccountServiceStatus
        """

        self._account_status = account_status

    @property
    def account_type(self):
        """Gets the account_type of this Account.  # noqa: E501


        :return: The account_type of this Account.  # noqa: E501
        :rtype: AccountServiceType
        """
        return self._account_type

    @account_type.setter
    def account_type(self, account_type):
        """Sets the account_type of this Account.


        :param account_type: The account_type of this Account.  # noqa: E501
        :type: AccountServiceType
        """

        self._account_type = account_type

    @property
    def auth_type(self):
        """Gets the auth_type of this Account.  # noqa: E501


        :return: The auth_type of this Account.  # noqa: E501
        :rtype: AccountServiceAuthType
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """Sets the auth_type of this Account.


        :param auth_type: The auth_type of this Account.  # noqa: E501
        :type: AccountServiceAuthType
        """

        self._auth_type = auth_type

    @property
    def auto_tagging_enabled(self):
        """Gets the auto_tagging_enabled of this Account.  # noqa: E501


        :return: The auto_tagging_enabled of this Account.  # noqa: E501
        :rtype: AccountServiceAutoTaggingEnabled
        """
        return self._auto_tagging_enabled

    @auto_tagging_enabled.setter
    def auto_tagging_enabled(self, auto_tagging_enabled):
        """Sets the auto_tagging_enabled of this Account.


        :param auto_tagging_enabled: The auto_tagging_enabled of this Account.  # noqa: E501
        :type: AccountServiceAutoTaggingEnabled
        """

        self._auto_tagging_enabled = auto_tagging_enabled

    @property
    def budget(self):
        """Gets the budget of this Account.  # noqa: E501


        :return: The budget of this Account.  # noqa: E501
        :rtype: AccountServiceBudget
        """
        return self._budget

    @budget.setter
    def budget(self, budget):
        """Sets the budget of this Account.


        :param budget: The budget of this Account.  # noqa: E501
        :type: AccountServiceBudget
        """

        self._budget = budget

    @property
    def delivery_status(self):
        """Gets the delivery_status of this Account.  # noqa: E501


        :return: The delivery_status of this Account.  # noqa: E501
        :rtype: AccountServiceDeliveryStatus
        """
        return self._delivery_status

    @delivery_status.setter
    def delivery_status(self, delivery_status):
        """Sets the delivery_status of this Account.


        :param delivery_status: The delivery_status of this Account.  # noqa: E501
        :type: AccountServiceDeliveryStatus
        """

        self._delivery_status = delivery_status

    @property
    def is_test_account(self):
        """Gets the is_test_account of this Account.  # noqa: E501


        :return: The is_test_account of this Account.  # noqa: E501
        :rtype: AccountServiceIsTestAccount
        """
        return self._is_test_account

    @is_test_account.setter
    def is_test_account(self, is_test_account):
        """Sets the is_test_account of this Account.


        :param is_test_account: The is_test_account of this Account.  # noqa: E501
        :type: AccountServiceIsTestAccount
        """

        self._is_test_account = is_test_account

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Account):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class ReportDefinitionServiceFieldAttribute(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_field_name_en': 'str',
        'display_field_name_ja': 'str',
        'field_name': 'str',
        'field_type': 'str',
        'filterable': 'bool',
        'impossible_combination_fields': 'list[str]',
        'xml_attribute_name': 'str'
    }

    attribute_map = {
        'display_field_name_en': 'displayFieldNameEN',
        'display_field_name_ja': 'displayFieldNameJA',
        'field_name': 'fieldName',
        'field_type': 'fieldType',
        'filterable': 'filterable',
        'impossible_combination_fields': 'impossibleCombinationFields',
        'xml_attribute_name': 'xmlAttributeName'
    }

    def __init__(self, display_field_name_en=None, display_field_name_ja=None, field_name=None, field_type=None, filterable=None, impossible_combination_fields=None, xml_attribute_name=None, local_vars_configuration=None):  # noqa: E501
        """ReportDefinitionServiceFieldAttribute - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_field_name_en = None
        self._display_field_name_ja = None
        self._field_name = None
        self._field_type = None
        self._filterable = None
        self._impossible_combination_fields = None
        self._xml_attribute_name = None
        self.discriminator = None

        self.display_field_name_en = display_field_name_en
        self.display_field_name_ja = display_field_name_ja
        self.field_name = field_name
        self.field_type = field_type
        self.filterable = filterable
        self.impossible_combination_fields = impossible_combination_fields
        self.xml_attribute_name = xml_attribute_name

    @property
    def display_field_name_en(self):
        """Gets the display_field_name_en of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">ダウンロードされたレポートに表示されるフィールド名（英語）です。</div> <div lang=\"en\">Field Name for the Downloaded Report (EN).</div>   # noqa: E501

        :return: The display_field_name_en of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: str
        """
        return self._display_field_name_en

    @display_field_name_en.setter
    def display_field_name_en(self, display_field_name_en):
        """Sets the display_field_name_en of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">ダウンロードされたレポートに表示されるフィールド名（英語）です。</div> <div lang=\"en\">Field Name for the Downloaded Report (EN).</div>   # noqa: E501

        :param display_field_name_en: The display_field_name_en of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: str
        """

        self._display_field_name_en = display_field_name_en

    @property
    def display_field_name_ja(self):
        """Gets the display_field_name_ja of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">ダウンロードされたレポートに表示されるフィールド名（日本語）です。</div> <div lang=\"en\">Field Name for the Downloaded Report (JA).</div>   # noqa: E501

        :return: The display_field_name_ja of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: str
        """
        return self._display_field_name_ja

    @display_field_name_ja.setter
    def display_field_name_ja(self, display_field_name_ja):
        """Sets the display_field_name_ja of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">ダウンロードされたレポートに表示されるフィールド名（日本語）です。</div> <div lang=\"en\">Field Name for the Downloaded Report (JA).</div>   # noqa: E501

        :param display_field_name_ja: The display_field_name_ja of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: str
        """

        self._display_field_name_ja = display_field_name_ja

    @property
    def field_name(self):
        """Gets the field_name of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">フィールド名です。</div> <div lang=\"en\">Field Name.</div>   # noqa: E501

        :return: The field_name of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">フィールド名です。</div> <div lang=\"en\">Field Name.</div>   # noqa: E501

        :param field_name: The field_name of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def field_type(self):
        """Gets the field_type of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">フィールドタイプ（数字、文字列、ENUM値など）です。</div> <div lang=\"en\">Field type (number, string, ENUM, etc.)</div>   # noqa: E501

        :return: The field_type of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">フィールドタイプ（数字、文字列、ENUM値など）です。</div> <div lang=\"en\">Field type (number, string, ENUM, etc.)</div>   # noqa: E501

        :param field_type: The field_type of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: str
        """

        self._field_type = field_type

    @property
    def filterable(self):
        """Gets the filterable of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">フィールドのフィルター指定可否（true：フィルター指定可能なフィールド）です。</div> <div lang=\"en\">Whether the field filter can be specified or not (true: Filter can be specified).</div>   # noqa: E501

        :return: The filterable of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: bool
        """
        return self._filterable

    @filterable.setter
    def filterable(self, filterable):
        """Sets the filterable of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">フィールドのフィルター指定可否（true：フィルター指定可能なフィールド）です。</div> <div lang=\"en\">Whether the field filter can be specified or not (true: Filter can be specified).</div>   # noqa: E501

        :param filterable: The filterable of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: bool
        """

        self._filterable = filterable

    @property
    def impossible_combination_fields(self):
        """Gets the impossible_combination_fields of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">組み合わせ不可フィールドです。</div> <div lang=\"en\">Invalid field combinations.</div>   # noqa: E501

        :return: The impossible_combination_fields of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: list[str]
        """
        return self._impossible_combination_fields

    @impossible_combination_fields.setter
    def impossible_combination_fields(self, impossible_combination_fields):
        """Sets the impossible_combination_fields of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">組み合わせ不可フィールドです。</div> <div lang=\"en\">Invalid field combinations.</div>   # noqa: E501

        :param impossible_combination_fields: The impossible_combination_fields of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: list[str]
        """

        self._impossible_combination_fields = impossible_combination_fields

    @property
    def xml_attribute_name(self):
        """Gets the xml_attribute_name of this ReportDefinitionServiceFieldAttribute.  # noqa: E501

        <div lang=\"ja\">ダウンロードしたレポートのXML属性です。</div> <div lang=\"en\">XML attribute for the Downloaded Report.</div>   # noqa: E501

        :return: The xml_attribute_name of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :rtype: str
        """
        return self._xml_attribute_name

    @xml_attribute_name.setter
    def xml_attribute_name(self, xml_attribute_name):
        """Sets the xml_attribute_name of this ReportDefinitionServiceFieldAttribute.

        <div lang=\"ja\">ダウンロードしたレポートのXML属性です。</div> <div lang=\"en\">XML attribute for the Downloaded Report.</div>   # noqa: E501

        :param xml_attribute_name: The xml_attribute_name of this ReportDefinitionServiceFieldAttribute.  # noqa: E501
        :type: str
        """

        self._xml_attribute_name = xml_attribute_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportDefinitionServiceFieldAttribute):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReportDefinitionServiceFieldAttribute):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from yahoo_ads_display.api_client import ApiClient
from yahoo_ads_display.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class VideoServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def video_service_download_post(self, **kwargs):  # noqa: E501
        """video_service_download_post  # noqa: E501

        <div lang=\"ja\">入稿済の動画をダウンロードします。</div> <div lang=\"en\">Downloads the added video.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_download_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceDownloadSelector video_service_download_selector:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.video_service_download_post_with_http_info(**kwargs)  # noqa: E501

    def video_service_download_post_with_http_info(self, **kwargs):  # noqa: E501
        """video_service_download_post  # noqa: E501

        <div lang=\"ja\">入稿済の動画をダウンロードします。</div> <div lang=\"en\">Downloads the added video.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_download_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceDownloadSelector video_service_download_selector:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'video_service_download_selector'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_service_download_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_service_download_selector' in local_var_params:
            body_params = local_var_params['video_service_download_selector']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/VideoService/download', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_service_get_post(self, **kwargs):  # noqa: E501
        """video_service_get_post  # noqa: E501

        <div lang=\"ja\">入稿済の動画の情報を取得します。</div> <div lang=\"en\">Retrieves the added video information.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_get_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceSelector video_service_selector:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VideoServiceGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.video_service_get_post_with_http_info(**kwargs)  # noqa: E501

    def video_service_get_post_with_http_info(self, **kwargs):  # noqa: E501
        """video_service_get_post  # noqa: E501

        <div lang=\"ja\">入稿済の動画の情報を取得します。</div> <div lang=\"en\">Retrieves the added video information.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_get_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceSelector video_service_selector:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VideoServiceGetResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'video_service_selector'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_service_get_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_service_selector' in local_var_params:
            body_params = local_var_params['video_service_selector']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/VideoService/get', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VideoServiceGetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_service_remove_post(self, **kwargs):  # noqa: E501
        """video_service_remove_post  # noqa: E501

        <div lang=\"ja\">入稿済みの動画を削除します。</div> <div lang=\"en\">Removes the added videos.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_remove_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceOperation video_service_operation:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VideoServiceMutateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.video_service_remove_post_with_http_info(**kwargs)  # noqa: E501

    def video_service_remove_post_with_http_info(self, **kwargs):  # noqa: E501
        """video_service_remove_post  # noqa: E501

        <div lang=\"ja\">入稿済みの動画を削除します。</div> <div lang=\"en\">Removes the added videos.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_remove_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceOperation video_service_operation:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VideoServiceMutateResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'video_service_operation'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_service_remove_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_service_operation' in local_var_params:
            body_params = local_var_params['video_service_operation']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/VideoService/remove', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VideoServiceMutateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_service_set_post(self, **kwargs):  # noqa: E501
        """video_service_set_post  # noqa: E501

        <div lang=\"ja\">入稿済の動画の情報（動画名、配信状況）を変更します。</div> <div lang=\"en\">Updates information (Video Name and Display Status) of added videos.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_set_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceOperation video_service_operation:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VideoServiceMutateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.video_service_set_post_with_http_info(**kwargs)  # noqa: E501

    def video_service_set_post_with_http_info(self, **kwargs):  # noqa: E501
        """video_service_set_post  # noqa: E501

        <div lang=\"ja\">入稿済の動画の情報（動画名、配信状況）を変更します。</div> <div lang=\"en\">Updates information (Video Name and Display Status) of added videos.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_set_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VideoServiceOperation video_service_operation:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VideoServiceMutateResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'video_service_operation'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_service_set_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_service_operation' in local_var_params:
            body_params = local_var_params['video_service_operation']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/VideoService/set', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VideoServiceMutateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_service_upload_post(self, account_id, video_name, video_title, user_status, **kwargs):  # noqa: E501
        """video_service_upload_post  # noqa: E501

        <div lang=\"ja\">動画ファイルのアップロード処理を実施します。</div> <div lang=\"en\">Upload process of video files can be operated.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_upload_post(account_id, video_name, video_title, user_status, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int account_id: <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>  (required)
        :param str video_name: <div lang=\"ja\">動画のファイル名です。</div> <div lang=\"en\">Video file name.</div>  (required)
        :param str video_title: <div lang=\"ja\">動画名です。</div> <div lang=\"en\">Video name.</div>  (required)
        :param VideoServiceUserStatus user_status: <div lang=\"ja\">ユーザーにより広告配信の有無を調整できる設定です。</div> <div lang=\"en\">Ad delivery status that can be set by an user is served.</div>  (required)
        :param file file:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VideoServiceUploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.video_service_upload_post_with_http_info(account_id, video_name, video_title, user_status, **kwargs)  # noqa: E501

    def video_service_upload_post_with_http_info(self, account_id, video_name, video_title, user_status, **kwargs):  # noqa: E501
        """video_service_upload_post  # noqa: E501

        <div lang=\"ja\">動画ファイルのアップロード処理を実施します。</div> <div lang=\"en\">Upload process of video files can be operated.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_service_upload_post_with_http_info(account_id, video_name, video_title, user_status, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int account_id: <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>  (required)
        :param str video_name: <div lang=\"ja\">動画のファイル名です。</div> <div lang=\"en\">Video file name.</div>  (required)
        :param str video_title: <div lang=\"ja\">動画名です。</div> <div lang=\"en\">Video name.</div>  (required)
        :param VideoServiceUserStatus user_status: <div lang=\"ja\">ユーザーにより広告配信の有無を調整できる設定です。</div> <div lang=\"en\">Ad delivery status that can be set by an user is served.</div>  (required)
        :param file file:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VideoServiceUploadResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_id',
            'video_name',
            'video_title',
            'user_status',
            'file'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_service_upload_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `account_id` when calling `video_service_upload_post`")  # noqa: E501
        # verify the required parameter 'video_name' is set
        if self.api_client.client_side_validation and ('video_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['video_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `video_name` when calling `video_service_upload_post`")  # noqa: E501
        # verify the required parameter 'video_title' is set
        if self.api_client.client_side_validation and ('video_title' not in local_var_params or  # noqa: E501
                                                        local_var_params['video_title'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `video_title` when calling `video_service_upload_post`")  # noqa: E501
        # verify the required parameter 'user_status' is set
        if self.api_client.client_side_validation and ('user_status' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_status'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_status` when calling `video_service_upload_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'account_id' in local_var_params and local_var_params['account_id'] is not None:  # noqa: E501
            query_params.append(('accountId', local_var_params['account_id']))  # noqa: E501
        if 'video_name' in local_var_params and local_var_params['video_name'] is not None:  # noqa: E501
            query_params.append(('videoName', local_var_params['video_name']))  # noqa: E501
        if 'video_title' in local_var_params and local_var_params['video_title'] is not None:  # noqa: E501
            query_params.append(('videoTitle', local_var_params['video_title']))  # noqa: E501
        if 'user_status' in local_var_params and local_var_params['user_status'] is not None:  # noqa: E501
            query_params.append(('userStatus', local_var_params['user_status']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/VideoService/upload', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VideoServiceUploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import yahoo_ads_display
from yahoo_ads_display.api.campaign_service_api import CampaignServiceApi  # noqa: E501
from yahoo_ads_display.rest import ApiException


class TestCampaignServiceApi(unittest.TestCase):
    """CampaignServiceApi unit test stubs"""

    def setUp(self):
        self.api = yahoo_ads_display.api.campaign_service_api.CampaignServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_campaign_service_add_post(self):
        """Test case for campaign_service_add_post

        """
        pass

    def test_campaign_service_get_post(self):
        """Test case for campaign_service_get_post

        """
        pass

    def test_campaign_service_remove_post(self):
        """Test case for campaign_service_remove_post

        """
        pass

    def test_campaign_service_set_post(self):
        """Test case for campaign_service_set_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group_ad_service_ad import AdGroupAdServiceAd  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroupAdServiceAd(unittest.TestCase):
    """AdGroupAdServiceAd unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroupAdServiceAd
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group_ad_service_ad.AdGroupAdServiceAd()  # noqa: E501
        if include_optional :
            return AdGroupAdServiceAd(
                ad_type = 'TEXT_LONG_AD1',
                banner_image_ad = yahoo_ads_display.models.ad_group_ad_service_banner_image_ad.AdGroupAdServiceBannerImageAd(
                    display_url = '0',
                    url = '0', ),
                banner_video_ad = yahoo_ads_display.models.ad_group_ad_service_banner_video_ad.AdGroupAdServiceBannerVideoAd(
                    display_url = '0',
                    is_remove_video10_sec_beacon_urls = 'TRUE',
                    is_remove_video25_percent_beacon_urls = 'TRUE',
                    is_remove_video3_sec_beacon_urls = 'TRUE',
                    is_remove_video50_percent_beacon_urls = 'TRUE',
                    is_remove_video75_percent_beacon_urls = 'TRUE',
                    is_remove_video_complete_beacon_urls = 'TRUE',
                    is_remove_video_start_beacon_urls = 'TRUE',
                    thumbnail_media_id = 56,
                    url = '0',
                    video10_sec_beacon_urls = [
                        '0'
                        ],
                    video25_percent_beacon_urls = [
                        '0'
                        ],
                    video3_sec_beacon_urls = [
                        '0'
                        ],
                    video50_percent_beacon_urls = [
                        '0'
                        ],
                    video75_percent_beacon_urls = [
                        '0'
                        ],
                    video_complete_beacon_urls = [
                        '0'
                        ],
                    video_start_beacon_urls = [
                        '0'
                        ], ),
                dynamic_ad = yahoo_ads_display.models.ad_group_ad_service_dynamic_ad.AdGroupAdServiceDynamicAd(
                    brand_color = '0',
                    button_text = 'FOR_MORE_INFO',
                    campaign_banner_media_id = 56,
                    campaign_banner_media_id2 = 56,
                    campaign_banner_media_id3 = 56,
                    campaign_banner_media_id4 = 56,
                    campaign_banner_url = '0',
                    display_url = '0',
                    is_remove_campaign_banner_media_id = 'TRUE',
                    is_remove_campaign_banner_media_id2 = 'TRUE',
                    is_remove_campaign_banner_media_id3 = 'TRUE',
                    is_remove_campaign_banner_media_id4 = 'TRUE',
                    is_remove_campaign_banner_url = 'TRUE',
                    logo_media_id = 56,
                    logo_media_id2 = 56,
                    logo_media_id3 = 56,
                    prefix = '0',
                    principal = '0',
                    suffix = '0',
                    url = '0', ),
                mobile_ad = yahoo_ads_display.models.ad_group_ad_service_mobile_ad.AdGroupAdServiceMobileAd(
                    description = '0',
                    description2 = '0',
                    display_url = '0',
                    headline = '0',
                    mobile_carriers = [
                        'DOCOMO'
                        ],
                    url = '0', ),
                pos_ad = yahoo_ads_display.models.ad_group_ad_service_pos_ad.AdGroupAdServicePosAd(
                    description = '0',
                    url = '0', ),
                responsive_image_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_image_ad.AdGroupAdServiceResponsiveImageAd(
                    button_text = 'FOR_MORE_INFO',
                    description = '0',
                    display_url = '0',
                    headline = '0',
                    logo_media_id = 56,
                    principal = '0',
                    url = '0', ),
                responsive_video_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_video_ad.AdGroupAdServiceResponsiveVideoAd(
                    button_text = 'FOR_MORE_INFO',
                    description = '0',
                    display_url = '0',
                    headline = '0',
                    is_remove_video10_sec_beacon_urls = 'TRUE',
                    is_remove_video25_percent_beacon_urls = 'TRUE',
                    is_remove_video3_sec_beacon_urls = 'TRUE',
                    is_remove_video50_percent_beacon_urls = 'TRUE',
                    is_remove_video75_percent_beacon_urls = 'TRUE',
                    is_remove_video_complete_beacon_urls = 'TRUE',
                    is_remove_video_start_beacon_urls = 'TRUE',
                    logo_media_id = 56,
                    principal = '0',
                    thumbnail_media_id = 56,
                    url = '0',
                    video10_sec_beacon_urls = [
                        '0'
                        ],
                    video25_percent_beacon_urls = [
                        '0'
                        ],
                    video3_sec_beacon_urls = [
                        '0'
                        ],
                    video50_percent_beacon_urls = [
                        '0'
                        ],
                    video75_percent_beacon_urls = [
                        '0'
                        ],
                    video_complete_beacon_urls = [
                        '0'
                        ],
                    video_start_beacon_urls = [
                        '0'
                        ], ),
                static_frame_ad = yahoo_ads_display.models.ad_group_ad_service_static_frame_ad.AdGroupAdServiceStaticFrameAd(
                    button_text = 'FOR_MORE_INFO',
                    color_set_id = 56,
                    description = '0',
                    display_url = '0',
                    headline = '0',
                    layout = '0',
                    logo_media_id = 56,
                    principal = '0',
                    size = '0',
                    url = '0', ),
                text_ad = yahoo_ads_display.models.ad_group_ad_service_text_ad.AdGroupAdServiceTextAd(
                    description = '0',
                    description2 = '0',
                    display_url = '0',
                    headline = '0',
                    url = '0', )
            )
        else :
            return AdGroupAdServiceAd(
        )

    def testAdGroupAdServiceAd(self):
        """Test AdGroupAdServiceAd"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class FeedFtp(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'active_status': 'FeedFtpServiceActiveStatus',
        'feed_id': 'int',
        'feed_url': 'str',
        'item_list_upload_type': 'FeedFtpServiceItemListUploadType',
        'schedule': 'FeedFtpServiceSchedule',
        'user_name': 'str',
        'user_password': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'active_status': 'activeStatus',
        'feed_id': 'feedId',
        'feed_url': 'feedUrl',
        'item_list_upload_type': 'itemListUploadType',
        'schedule': 'schedule',
        'user_name': 'userName',
        'user_password': 'userPassword'
    }

    def __init__(self, account_id=None, active_status=None, feed_id=None, feed_url=None, item_list_upload_type=None, schedule=None, user_name=None, user_password=None, local_vars_configuration=None):  # noqa: E501
        """FeedFtp - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._active_status = None
        self._feed_id = None
        self._feed_url = None
        self._item_list_upload_type = None
        self._schedule = None
        self._user_name = None
        self._user_password = None
        self.discriminator = None

        self.account_id = account_id
        self.active_status = active_status
        self.feed_id = feed_id
        self.feed_url = feed_url
        self.item_list_upload_type = item_list_upload_type
        self.schedule = schedule
        self.user_name = user_name
        self.user_password = user_password

    @property
    def account_id(self):
        """Gets the account_id of this FeedFtp.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Account ID.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The account_id of this FeedFtp.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this FeedFtp.

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Account ID.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param account_id: The account_id of this FeedFtp.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def active_status(self):
        """Gets the active_status of this FeedFtp.  # noqa: E501


        :return: The active_status of this FeedFtp.  # noqa: E501
        :rtype: FeedFtpServiceActiveStatus
        """
        return self._active_status

    @active_status.setter
    def active_status(self, active_status):
        """Sets the active_status of this FeedFtp.


        :param active_status: The active_status of this FeedFtp.  # noqa: E501
        :type: FeedFtpServiceActiveStatus
        """

        self._active_status = active_status

    @property
    def feed_id(self):
        """Gets the feed_id of this FeedFtp.  # noqa: E501

        <div lang=\"ja\"> Feedを識別するIdです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Feed ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The feed_id of this FeedFtp.  # noqa: E501
        :rtype: int
        """
        return self._feed_id

    @feed_id.setter
    def feed_id(self, feed_id):
        """Sets the feed_id of this FeedFtp.

        <div lang=\"ja\"> Feedを識別するIdです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\"> Feed ID.<br> This field is required in requests. </div>   # noqa: E501

        :param feed_id: The feed_id of this FeedFtp.  # noqa: E501
        :type: int
        """

        self._feed_id = feed_id

    @property
    def feed_url(self):
        """Gets the feed_url of this FeedFtp.  # noqa: E501

        <div lang=\"ja\"> 商品リストファイルのURLです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> URL of item list file.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The feed_url of this FeedFtp.  # noqa: E501
        :rtype: str
        """
        return self._feed_url

    @feed_url.setter
    def feed_url(self, feed_url):
        """Sets the feed_url of this FeedFtp.

        <div lang=\"ja\"> 商品リストファイルのURLです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> URL of item list file.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param feed_url: The feed_url of this FeedFtp.  # noqa: E501
        :type: str
        """

        self._feed_url = feed_url

    @property
    def item_list_upload_type(self):
        """Gets the item_list_upload_type of this FeedFtp.  # noqa: E501


        :return: The item_list_upload_type of this FeedFtp.  # noqa: E501
        :rtype: FeedFtpServiceItemListUploadType
        """
        return self._item_list_upload_type

    @item_list_upload_type.setter
    def item_list_upload_type(self, item_list_upload_type):
        """Sets the item_list_upload_type of this FeedFtp.


        :param item_list_upload_type: The item_list_upload_type of this FeedFtp.  # noqa: E501
        :type: FeedFtpServiceItemListUploadType
        """

        self._item_list_upload_type = item_list_upload_type

    @property
    def schedule(self):
        """Gets the schedule of this FeedFtp.  # noqa: E501


        :return: The schedule of this FeedFtp.  # noqa: E501
        :rtype: FeedFtpServiceSchedule
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this FeedFtp.


        :param schedule: The schedule of this FeedFtp.  # noqa: E501
        :type: FeedFtpServiceSchedule
        """

        self._schedule = schedule

    @property
    def user_name(self):
        """Gets the user_name of this FeedFtp.  # noqa: E501

        <div lang=\"ja\"> ユーザー名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> User name.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The user_name of this FeedFtp.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this FeedFtp.

        <div lang=\"ja\"> ユーザー名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> User name.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param user_name: The user_name of this FeedFtp.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def user_password(self):
        """Gets the user_password of this FeedFtp.  # noqa: E501

        <div lang=\"ja\"> パスワードです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Password.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The user_password of this FeedFtp.  # noqa: E501
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """Sets the user_password of this FeedFtp.

        <div lang=\"ja\"> パスワードです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Password.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param user_password: The user_password of this FeedFtp.  # noqa: E501
        :type: str
        """

        self._user_password = user_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedFtp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedFtp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from yahoo_ads_display.api_client import ApiClient
from yahoo_ads_display.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AccountAdProductServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def account_ad_product_service_get_post(self, **kwargs):  # noqa: E501
        """account_ad_product_service_get_post  # noqa: E501

        <div lang=\"ja\">アカウントで利用できる広告掲載方式を取得します。</div> <div lang=\"en\">Gets the ad display method that is available from account.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_ad_product_service_get_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccountAdProductServiceSelector account_ad_product_service_selector:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AccountAdProductServiceGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.account_ad_product_service_get_post_with_http_info(**kwargs)  # noqa: E501

    def account_ad_product_service_get_post_with_http_info(self, **kwargs):  # noqa: E501
        """account_ad_product_service_get_post  # noqa: E501

        <div lang=\"ja\">アカウントで利用できる広告掲載方式を取得します。</div> <div lang=\"en\">Gets the ad display method that is available from account.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_ad_product_service_get_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccountAdProductServiceSelector account_ad_product_service_selector:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AccountAdProductServiceGetResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_ad_product_service_selector'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_ad_product_service_get_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'account_ad_product_service_selector' in local_var_params:
            body_params = local_var_params['account_ad_product_service_selector']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/AccountAdProductService/get', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccountAdProductServiceGetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group import AdGroup  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroup(unittest.TestCase):
    """AdGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroup
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group.AdGroup()  # noqa: E501
        if include_optional :
            return AdGroup(
                account_id = 56,
                ad_group_bidding_strategy = yahoo_ads_display.models.ad_group_service_bidding_strategy.AdGroupServiceBiddingStrategy(
                    campaign_bidding_strategy_type = 'AUTO',
                    max_cpc_bid_value = 56,
                    max_cpv_bid_value = 56,
                    max_vcpm_bid_value = 56,
                    target_cpa_bid_value = 56, ),
                ad_group_id = 56,
                ad_group_name = '0',
                bid = yahoo_ads_display.models.ad_group_service_bid.AdGroupServiceBid(
                    manual_cpc_bid = yahoo_ads_display.models.ad_group_service_manual_cpc_bid.AdGroupServiceManualCPCBid(
                        max_cpc = 56, ),
                    manual_cpv_bid = yahoo_ads_display.models.ad_group_service_manual_cpv_bid.AdGroupServiceManualCPVBid(
                        max_cpv = 56, ),
                    type = 'MANUAL_CPC', ),
                campaign_id = 56,
                campaign_name = '0',
                conversion_optimizer = yahoo_ads_display.models.ad_group_service_conversion_optimizer.AdGroupServiceConversionOptimizer(
                    auto_conversion_optimizer = yahoo_ads_display.models.ad_group_service_auto_conversion_optimizer.AdGroupServiceAutoConversionOptimizer(
                        eligibility_flg = 'ENABLE',
                        target_cpa = 56, ),
                    manual_conversion_optimizer = yahoo_ads_display.models.ad_group_service_manual_conversion_optimizer.AdGroupServiceManualConversionOptimizer(),
                    none_conversion_optimizer = yahoo_ads_display.models.ad_group_service_none_conversion_optimizer.AdGroupServiceNoneConversionOptimizer(),
                    optimizer_type = 'NONE', ),
                device = [
                    'DESKTOP'
                    ],
                device_app = [
                    'APP'
                    ],
                device_os = [
                    'IOS'
                    ],
                device_os_version = '0',
                dynamic_image_extensions = 'ACTIVE',
                feed_set_id = 56,
                is_remove_feed_set_id = True,
                labels = [
                    yahoo_ads_display.models.ad_group_service_label.AdGroupServiceLabel(
                        color = '0',
                        description = '0',
                        label_id = 56,
                        label_name = '0', )
                    ],
                smart_device_carriers = [
                    'DOCOMO'
                    ],
                user_status = 'ACTIVE'
            )
        else :
            return AdGroup(
        )

    def testAdGroup(self):
        """Test AdGroup"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class FeedFtpRequestServiceOperation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'operand': 'list[FeedFtpRequest]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'operand': 'operand'
    }

    def __init__(self, account_id=None, operand=None, local_vars_configuration=None):  # noqa: E501
        """FeedFtpRequestServiceOperation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._operand = None
        self.discriminator = None

        self.account_id = account_id
        self.operand = operand

    @property
    def account_id(self):
        """Gets the account_id of this FeedFtpRequestServiceOperation.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">account Id</div>   # noqa: E501

        :return: The account_id of this FeedFtpRequestServiceOperation.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this FeedFtpRequestServiceOperation.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">account Id</div>   # noqa: E501

        :param account_id: The account_id of this FeedFtpRequestServiceOperation.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def operand(self):
        """Gets the operand of this FeedFtpRequestServiceOperation.  # noqa: E501


        :return: The operand of this FeedFtpRequestServiceOperation.  # noqa: E501
        :rtype: list[FeedFtpRequest]
        """
        return self._operand

    @operand.setter
    def operand(self, operand):
        """Sets the operand of this FeedFtpRequestServiceOperation.


        :param operand: The operand of this FeedFtpRequestServiceOperation.  # noqa: E501
        :type: list[FeedFtpRequest]
        """
        if self.local_vars_configuration.client_side_validation and operand is None:  # noqa: E501
            raise ValueError("Invalid value for `operand`, must not be `None`")  # noqa: E501

        self._operand = operand

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedFtpRequestServiceOperation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedFtpRequestServiceOperation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class StatsServiceValue(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'ad_group_stats_value': 'StatsServiceAdGroupStatsValue',
        'ad_stats_value': 'StatsServiceAdStatsValue',
        'campaign_stats_value': 'StatsServiceCampaignStatsValue',
        'errors': 'list[Error]',
        'image_stats_value': 'StatsServiceImageStatsValue',
        'operation_succeeded': 'bool',
        'period_custom_date': 'StatsServicePeriodCustomDate',
        'stats_period': 'StatsServiceStatsPeriod',
        'target_stats_value': 'StatsServiceTargetStatsValue',
        'type': 'StatsServiceType',
        'video_stats_value': 'StatsServiceVideoStatsValue'
    }

    attribute_map = {
        'account_id': 'accountId',
        'ad_group_stats_value': 'adGroupStatsValue',
        'ad_stats_value': 'adStatsValue',
        'campaign_stats_value': 'campaignStatsValue',
        'errors': 'errors',
        'image_stats_value': 'imageStatsValue',
        'operation_succeeded': 'operationSucceeded',
        'period_custom_date': 'periodCustomDate',
        'stats_period': 'statsPeriod',
        'target_stats_value': 'targetStatsValue',
        'type': 'type',
        'video_stats_value': 'videoStatsValue'
    }

    def __init__(self, account_id=None, ad_group_stats_value=None, ad_stats_value=None, campaign_stats_value=None, errors=None, image_stats_value=None, operation_succeeded=None, period_custom_date=None, stats_period=None, target_stats_value=None, type=None, video_stats_value=None, local_vars_configuration=None):  # noqa: E501
        """StatsServiceValue - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._ad_group_stats_value = None
        self._ad_stats_value = None
        self._campaign_stats_value = None
        self._errors = None
        self._image_stats_value = None
        self._operation_succeeded = None
        self._period_custom_date = None
        self._stats_period = None
        self._target_stats_value = None
        self._type = None
        self._video_stats_value = None
        self.discriminator = None

        self.account_id = account_id
        self.ad_group_stats_value = ad_group_stats_value
        self.ad_stats_value = ad_stats_value
        self.campaign_stats_value = campaign_stats_value
        self.errors = errors
        self.image_stats_value = image_stats_value
        self.operation_succeeded = operation_succeeded
        self.period_custom_date = period_custom_date
        self.stats_period = stats_period
        self.target_stats_value = target_stats_value
        self.type = type
        self.video_stats_value = video_stats_value

    @property
    def account_id(self):
        """Gets the account_id of this StatsServiceValue.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this StatsServiceValue.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this StatsServiceValue.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this StatsServiceValue.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def ad_group_stats_value(self):
        """Gets the ad_group_stats_value of this StatsServiceValue.  # noqa: E501


        :return: The ad_group_stats_value of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceAdGroupStatsValue
        """
        return self._ad_group_stats_value

    @ad_group_stats_value.setter
    def ad_group_stats_value(self, ad_group_stats_value):
        """Sets the ad_group_stats_value of this StatsServiceValue.


        :param ad_group_stats_value: The ad_group_stats_value of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceAdGroupStatsValue
        """

        self._ad_group_stats_value = ad_group_stats_value

    @property
    def ad_stats_value(self):
        """Gets the ad_stats_value of this StatsServiceValue.  # noqa: E501


        :return: The ad_stats_value of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceAdStatsValue
        """
        return self._ad_stats_value

    @ad_stats_value.setter
    def ad_stats_value(self, ad_stats_value):
        """Sets the ad_stats_value of this StatsServiceValue.


        :param ad_stats_value: The ad_stats_value of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceAdStatsValue
        """

        self._ad_stats_value = ad_stats_value

    @property
    def campaign_stats_value(self):
        """Gets the campaign_stats_value of this StatsServiceValue.  # noqa: E501


        :return: The campaign_stats_value of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceCampaignStatsValue
        """
        return self._campaign_stats_value

    @campaign_stats_value.setter
    def campaign_stats_value(self, campaign_stats_value):
        """Sets the campaign_stats_value of this StatsServiceValue.


        :param campaign_stats_value: The campaign_stats_value of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceCampaignStatsValue
        """

        self._campaign_stats_value = campaign_stats_value

    @property
    def errors(self):
        """Gets the errors of this StatsServiceValue.  # noqa: E501


        :return: The errors of this StatsServiceValue.  # noqa: E501
        :rtype: list[Error]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this StatsServiceValue.


        :param errors: The errors of this StatsServiceValue.  # noqa: E501
        :type: list[Error]
        """

        self._errors = errors

    @property
    def image_stats_value(self):
        """Gets the image_stats_value of this StatsServiceValue.  # noqa: E501


        :return: The image_stats_value of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceImageStatsValue
        """
        return self._image_stats_value

    @image_stats_value.setter
    def image_stats_value(self, image_stats_value):
        """Sets the image_stats_value of this StatsServiceValue.


        :param image_stats_value: The image_stats_value of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceImageStatsValue
        """

        self._image_stats_value = image_stats_value

    @property
    def operation_succeeded(self):
        """Gets the operation_succeeded of this StatsServiceValue.  # noqa: E501

        <div lang=\"ja\">処理結果です。trueの場合は、処理は成功しました。falseの場合は処理が失敗しています。</div> <div lang=\"en\">The process results. If true, the process succeeded. If false, the process failed.</div>   # noqa: E501

        :return: The operation_succeeded of this StatsServiceValue.  # noqa: E501
        :rtype: bool
        """
        return self._operation_succeeded

    @operation_succeeded.setter
    def operation_succeeded(self, operation_succeeded):
        """Sets the operation_succeeded of this StatsServiceValue.

        <div lang=\"ja\">処理結果です。trueの場合は、処理は成功しました。falseの場合は処理が失敗しています。</div> <div lang=\"en\">The process results. If true, the process succeeded. If false, the process failed.</div>   # noqa: E501

        :param operation_succeeded: The operation_succeeded of this StatsServiceValue.  # noqa: E501
        :type: bool
        """

        self._operation_succeeded = operation_succeeded

    @property
    def period_custom_date(self):
        """Gets the period_custom_date of this StatsServiceValue.  # noqa: E501


        :return: The period_custom_date of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServicePeriodCustomDate
        """
        return self._period_custom_date

    @period_custom_date.setter
    def period_custom_date(self, period_custom_date):
        """Sets the period_custom_date of this StatsServiceValue.


        :param period_custom_date: The period_custom_date of this StatsServiceValue.  # noqa: E501
        :type: StatsServicePeriodCustomDate
        """

        self._period_custom_date = period_custom_date

    @property
    def stats_period(self):
        """Gets the stats_period of this StatsServiceValue.  # noqa: E501


        :return: The stats_period of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceStatsPeriod
        """
        return self._stats_period

    @stats_period.setter
    def stats_period(self, stats_period):
        """Sets the stats_period of this StatsServiceValue.


        :param stats_period: The stats_period of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceStatsPeriod
        """

        self._stats_period = stats_period

    @property
    def target_stats_value(self):
        """Gets the target_stats_value of this StatsServiceValue.  # noqa: E501


        :return: The target_stats_value of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceTargetStatsValue
        """
        return self._target_stats_value

    @target_stats_value.setter
    def target_stats_value(self, target_stats_value):
        """Sets the target_stats_value of this StatsServiceValue.


        :param target_stats_value: The target_stats_value of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceTargetStatsValue
        """

        self._target_stats_value = target_stats_value

    @property
    def type(self):
        """Gets the type of this StatsServiceValue.  # noqa: E501


        :return: The type of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StatsServiceValue.


        :param type: The type of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceType
        """

        self._type = type

    @property
    def video_stats_value(self):
        """Gets the video_stats_value of this StatsServiceValue.  # noqa: E501


        :return: The video_stats_value of this StatsServiceValue.  # noqa: E501
        :rtype: StatsServiceVideoStatsValue
        """
        return self._video_stats_value

    @video_stats_value.setter
    def video_stats_value(self, video_stats_value):
        """Sets the video_stats_value of this StatsServiceValue.


        :param video_stats_value: The video_stats_value of this StatsServiceValue.  # noqa: E501
        :type: StatsServiceVideoStatsValue
        """

        self._video_stats_value = video_stats_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatsServiceValue):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StatsServiceValue):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.conversion_tracker_service_operation import ConversionTrackerServiceOperation  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestConversionTrackerServiceOperation(unittest.TestCase):
    """ConversionTrackerServiceOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConversionTrackerServiceOperation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.conversion_tracker_service_operation.ConversionTrackerServiceOperation()  # noqa: E501
        if include_optional :
            return ConversionTrackerServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.conversion_tracker.ConversionTracker(
                        account_id = 56,
                        all_conversion_value = '0',
                        all_conversions = 56,
                        app_conversion = yahoo_ads_display.models.conversion_tracker_service_app_conversion.ConversionTrackerServiceAppConversion(
                            app_conversion_platform = 'ITUNES',
                            app_conversion_type = 'FIRST_OPEN',
                            app_id = '0', ),
                        category = 'NONE',
                        conversion_tracker_id = 56,
                        conversion_tracker_name = '0',
                        conversion_tracker_type = 'WEB_CONVERSION',
                        conversion_value = '0',
                        conversion_value_via_ad_click = '0',
                        conversions = 56,
                        conversions_via_ad_click = 56,
                        counting_type = 'ONE_PER_CLICK',
                        cross_device_conversions = 56,
                        exclude_from_bidding = 'FALSE',
                        measurement_period = 56,
                        measurement_period_view = 56,
                        most_recent_conversion_date = '0',
                        status = 'ENABLED',
                        user_revenue_value = 56,
                        web_conversion = yahoo_ads_display.models.conversion_tracker_service_web_conversion.ConversionTrackerServiceWebConversion(
                            snippet = [
                                yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet.ConversionTrackerServiceWebConversionSnippet(
                                    tag = '0',
                                    web_conversion_snippet_type = 'IMG', )
                                ], ), )
                    ]
            )
        else :
            return ConversionTrackerServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.conversion_tracker.ConversionTracker(
                        account_id = 56,
                        all_conversion_value = '0',
                        all_conversions = 56,
                        app_conversion = yahoo_ads_display.models.conversion_tracker_service_app_conversion.ConversionTrackerServiceAppConversion(
                            app_conversion_platform = 'ITUNES',
                            app_conversion_type = 'FIRST_OPEN',
                            app_id = '0', ),
                        category = 'NONE',
                        conversion_tracker_id = 56,
                        conversion_tracker_name = '0',
                        conversion_tracker_type = 'WEB_CONVERSION',
                        conversion_value = '0',
                        conversion_value_via_ad_click = '0',
                        conversions = 56,
                        conversions_via_ad_click = 56,
                        counting_type = 'ONE_PER_CLICK',
                        cross_device_conversions = 56,
                        exclude_from_bidding = 'FALSE',
                        measurement_period = 56,
                        measurement_period_view = 56,
                        most_recent_conversion_date = '0',
                        status = 'ENABLED',
                        user_revenue_value = 56,
                        web_conversion = yahoo_ads_display.models.conversion_tracker_service_web_conversion.ConversionTrackerServiceWebConversion(
                            snippet = [
                                yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet.ConversionTrackerServiceWebConversionSnippet(
                                    tag = '0',
                                    web_conversion_snippet_type = 'IMG', )
                                ], ), )
                    ],
        )

    def testConversionTrackerServiceOperation(self):
        """Test ConversionTrackerServiceOperation"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.campaign_service_get_response import CampaignServiceGetResponse  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestCampaignServiceGetResponse(unittest.TestCase):
    """CampaignServiceGetResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CampaignServiceGetResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.campaign_service_get_response.CampaignServiceGetResponse()  # noqa: E501
        if include_optional :
            return CampaignServiceGetResponse(
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                rid = '0',
                rval = yahoo_ads_display.models.campaign_service_page.CampaignServicePage(
                    total_num_entries = 56,
                    values = [
                        yahoo_ads_display.models.campaign_service_value.CampaignServiceValue(
                            campaign = yahoo_ads_display.models.campaign.Campaign(
                                account_id = 56,
                                ad_product_type = '0',
                                app_id = '0',
                                app_name = '0',
                                bidding_strategy = yahoo_ads_display.models.campaign_service_bidding_strategy.CampaignServiceBiddingStrategy(
                                    bidding_strategy_type = 'MANUAL_CPC', ),
                                budget = yahoo_ads_display.models.campaign_service_budget.CampaignServiceBudget(
                                    amount = 56,
                                    budget_delivery_method = 'STANDARD', ),
                                campaign_bidding_strategy = yahoo_ads_display.models.campaign_service_campaign_bidding_strategy.CampaignServiceCampaignBiddingStrategy(
                                    campaign_bidding_strategy_type = 'AUTO',
                                    max_cpc_bid_value = 56,
                                    max_cpv_bid_value = 56,
                                    max_vcpm_bid_value = 56,
                                    target_cpa_bid_value = 56, ),
                                campaign_goal = '0',
                                campaign_id = 56,
                                campaign_name = '0',
                                conversion_optimizer = yahoo_ads_display.models.campaign_service_conversion_optimizer.CampaignServiceConversionOptimizer(
                                    auto_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_auto_campaign_conversion_optimizer.CampaignServiceAutoCampaignConversionOptimizer(
                                        conversion_optimizer_eligibility_flg = 'ENABLE',
                                        target_cpa = 56, ),
                                    conversion_optimizer_type = 'MANUAL',
                                    manual_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_manual_campaign_conversion_optimizer.CampaignServiceManualCampaignConversionOptimizer(
                                        conversion_optimizer_training_status = 'PROCESSING', ), ),
                                device_os_type = 'ANDROID',
                                end_date = '0',
                                feed_id = 56,
                                frequency_cap = yahoo_ads_display.models.campaign_service_frequency_cap.CampaignServiceFrequencyCap(
                                    frequency_level = 'CAMPAIGN',
                                    frequency_time_unit = 'DAY',
                                    impression = 56, ),
                                labels = [
                                    yahoo_ads_display.models.campaign_service_label.CampaignServiceLabel(
                                        color = '0',
                                        description = '0',
                                        label_id = 56,
                                        label_name = '0', )
                                    ],
                                serving_status = 'SERVING',
                                start_date = '0',
                                type = 'STANDARD',
                                user_status = 'ACTIVE',
                                viewable_frequency_cap = yahoo_ads_display.models.campaign_service_viewable_frequency_cap.CampaignServiceViewableFrequencyCap(
                                    v_imps = 56, ), ),
                            errors = [
                                yahoo_ads_display.models.error.Error(
                                    code = '0',
                                    message = '0',
                                    details = [
                                        yahoo_ads_display.models.error_detail.ErrorDetail(
                                            request_key = '0',
                                            request_value = '0', )
                                        ], )
                                ],
                            operation_succeeded = True, )
                        ], )
            )
        else :
            return CampaignServiceGetResponse(
        )

    def testCampaignServiceGetResponse(self):
        """Test CampaignServiceGetResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
